@@ -3,7 +3,7 @@
 use PDF::API2::Basic::PDF::File;
 use PDF::API2::Basic::PDF::Utils;
 use PDF::API2;
-
+use Scalar::Util qw(blessed);
 
 sub walk_obj {
     my ($objs,$spdf,$tpdf,$obj,@keys)=@_;
@@ -24,13 +24,13 @@ sub walk_obj {
 
   $objs->{scalar $obj}=$tobj;
 
-    if(ref($obj)=~/Array$/ || (UNIVERSAL::can($obj,'isa') && $obj->isa('PDF::API2::Basic::PDF::Array'))) {
+    if(ref($obj)=~/Array$/ || (blessed($obj) && $obj->isa('PDF::API2::Basic::PDF::Array'))) {
         $tobj->{' val'}=[];
-        foreach my $k ($obj->elementsof) {
+        foreach my $k ($obj->elements()) {
             $k->realise if(ref($k)=~/Objind$/);
             $tobj->add_elements(walk_obj($objs,$spdf,$tpdf,$k));
         }
-    } elsif(ref($obj)=~/Dict$/ || (UNIVERSAL::can($obj,'isa') && $obj->isa('PDF::API2::Basic::PDF::Dict'))) {
+    } elsif(ref($obj)=~/Dict$/ || (blessed($obj) && $obj->isa('PDF::API2::Basic::PDF::Dict'))) {
         @keys=keys(%{$tobj}) if(scalar @keys <1);
         foreach my $k (@keys) {
             next if($k=~/^ /);
@@ -63,6 +63,6 @@ $spdf=PDF::API2::Basic::PDF::File->open($ARGV[0]);
 $tpdf=PDF::API2::Basic::PDF::File->_new;
 $mycache={};
 $tpdf->{Root}=walk_obj($mycache,$spdf,$tpdf,$spdf->{Root});
-$tpdf->{Info}=walk_obj($mycache,$spdf,$tpdf,$spdf->{Info});
+$tpdf->{Info}=walk_obj($mycache,$spdf,$tpdf,$spdf->{Info}) if $spdf->{Info};
 
 $tpdf->out_file($ARGV[1]);
