@@ -1,26 +1,21 @@
-#=======================================================================
+# Code in the PDF::API2::Basic::PDF namespace was originally copied from the
+# Text::PDF distribution.
 #
-#   THIS IS A REUSED PERL MODULE, FOR PROPER LICENCING TERMS SEE BELOW:
+# Copyright Martin Hosken <Martin_Hosken@sil.org>
 #
-#   Copyright Martin Hosken <Martin_Hosken@sil.org>
-#
-#   No warranty or expression of effectiveness, least of all regarding
-#   anyone's safety, is implied in this software or documentation.
-#
-#   This specific module is licensed under the Perl Artistic License.
-#
-#=======================================================================
+# Martin Hosken's code may be used under the terms of the MIT license.
+# Subsequent versions of the code have the same license as PDF::API2.
+
 package PDF::API2::Basic::PDF::Objind;
 
 use strict;
 use warnings;
 
-our $VERSION = '2.037'; # VERSION
+our $VERSION = '2.048'; # VERSION
 
 =head1 NAME
 
-PDF::API2::Basic::PDF::Objind - PDF indirect object reference. Also acts as an abstract
-superclass for all elements in a PDF file.
+PDF::API2::Basic::PDF::Objind - Low-level PDF indirect object
 
 =head1 INSTANCE VARIABLES
 
@@ -115,6 +110,11 @@ sub release {
     my @tofree = values %$self;
     %$self = ();
 
+    # PDFs with highly-interconnected page trees or outlines can hit Perl's
+    # recursion limit pretty easily, so disable the warning for this specific
+    # loop.
+    no warnings 'recursion';
+
     while (my $item = shift @tofree) {
         # common case: value is not reference
         my $ref = ref($item) || next;
